pub fn scheduled_response(resp: ScheduledResult) -> ScheduleResultExpand description
Adapts a handler that may respond to the request itself.
pub fn scheduled_response(resp: ScheduledResult) -> ScheduleResultAdapts a handler that may respond to the request itself.